<?php
namespace EzSystems\Ezp23524Bundle\Command;
 
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Input\InputArgument;
use eZ\Publish\API\Repository\Values\Content\Query;
use eZ\Publish\API\Repository\Values\Content\Query\Criterion\Field;
use eZ\Publish\API\Repository\Values\Content\Query\Criterion\Operator;
 
class Ezp23524FieldfiltersFieldQueryCommand extends \Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand
{
    /**
     * Configures the command
     */
    protected function configure()
    {
        $this->setName( "ezsystems:ezp23524:fieldfiltersFieldQuery" );
        $this->setDefinition(
            array(
                new InputArgument( "searchInput", InputArgument::REQUIRED, "Text to search on field 'name' of content." ),
                new InputArgument( "languageCode", InputArgument::OPTIONAL, "Language code which to base content search upon (example: eng-GB, fre-FR, etc.)" ),
                new InputArgument( "notAlwaysAvailable", InputArgument::OPTIONAL, "Do not add main language to languages array (usage: add 'unavailable' after the language code used.)" )
            )
        );
    }
 
    /**
     * Executes the command
     * @param InputInterface $input
     * @param OutputInterface $output
     */
    protected function execute( InputInterface $input, OutputInterface $output )
    {
        /* Repo and services */
        $repository = $this->getContainer()->get("ezpublish.api.repository");
        $userService = $repository->getUserService();
        $searchService = $repository->getSearchService();

        $adminId = 14;
        $adminUser = $userService->loadUser( $adminId );
        $repository->setCurrentUser( $adminUser );

        /* Search parameters */
        $fieldToSearchOn = "name";
        $languageCode = $input->getArgument( "languageCode" );
        $searchInput = $input->getArgument( "searchInput" );
        $alwaysAvailable = $input->getArgument( "notAlwaysAvailable" );

        /* Querying */
        $query = new Query();
        $query->filter = new Field( $fieldToSearchOn, Operator::CONTAINS, $searchInput );
        if ( !empty( $languageCode ) )
        {
            if ( empty( $alwaysAvailable ) )
            {
                $output->writeln("Using 'useAlwaysAvailable': should encompass " . $languageCode . " plus main language."); /* TO REMOVE */
                $searchResult = $searchService->findContent( $query, array( "languages" => array( $languageCode ), "useAlwaysAvailable" => true ) );
            }
            else
            {
                if ( $alwaysAvailable === "unavailable" )
                {
                    $output->writeln("NOT using 'useAlwaysAvailable': should encompass " . $languageCode . " only."); /* TO REMOVE */
                    $searchResult = $searchService->findContent( $query, array( "languages" => array( $languageCode ), "useAlwaysAvailable" => false ) );
                }
            }
        }
        else
        {
            $output->writeln("NOT using languageCode: should encompass all languages"); /* TO REMOVE */
            $searchResult = $searchService->findContent( $query );
        }        

        /* Results */
        foreach( $searchResult->searchHits as $searchHit )
        {
            $output->writeln( $searchHit->valueObject->contentInfo->name );
        }
    }
}
