<?php
namespace EzSystems\Ezp23524Bundle\Command;

use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Input\InputArgument;
use eZ\Publish\API\Repository\Values\Content\Query;
use eZ\Publish\API\Repository\Values\Content\Query\Criterion\MapLocationDistance;
use eZ\Publish\API\Repository\Values\Content\Query\Criterion\Operator;

class Ezp23524FieldfiltersGMapQueryCommand extends \Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand
{

    /**
     * Configures the command
     */
    protected function configure()
    {
        $this->setName( "ezsystems:ezp23524:fieldfiltersGMapQuery" );
        $this->setDefinition(
            array(
                new InputArgument( "distance", InputArgument::REQUIRED, "Distance in kilometers up to how far contents will be searched." ),
                new InputArgument( "languageCode", InputArgument::OPTIONAL, "Language code which to base content search upon (example: eng-GB, fre-FR, etc.)" ),
                new InputArgument( "notAlwaysAvailable", InputArgument::OPTIONAL, "Do not add main language to languages array (usage: add 'unavailable' after the language code used.)" )
            )
        );
    }

    /**
     * Executes the command
     * @param InputInterface $input
     * @param OutputInterface $output
     */
    protected function execute( InputInterface $input, OutputInterface $output )
    {
        /* Repo and services */
        $repository = $this->getContainer()->get("ezpublish.api.repository");
        $userService = $repository->getUserService();
        $searchService = $repository->getSearchService();

        $adminId = 14;
        $adminUser = $userService->loadUser( $adminId );
        $repository->setCurrentUser( $adminUser );

        /* Search parameters */
        $mapFieldDefinition = "location";
        $distance = $input->getArgument( "distance" );
        $latitude = 38.709929578273396;
        $longitude = -9.132494031738247;
        $languageCode = $input->getArgument( "languageCode" );
        $alwaysAvailable = $input->getArgument( "notAlwaysAvailable" );

        /* Querying */
        $gmapCriterion = new MapLocationDistance( $mapFieldDefinition, Operator::LTE, $distance, $latitude, $longitude );
        $query = new Query();
        $query->filter = $gmapCriterion;
        if ( !empty( $languageCode ) )
        {
            if ( empty( $alwaysAvailable ) )
            {
                $output->writeln("Using 'useAlwaysAvailable': should encompass " . $languageCode . " plus main language."); /* TO REMOVOE */
                $searchResult = $searchService->findContent( $query, array( "languages" => array( $languageCode ), "useAlwaysAvailable" => true ) );
            }
            else
            {
                if ( $alwaysAvailable === "unavailable" )
                {
                    $output->writeln("NOT using 'useAlwaysAvailable': should encompass " . $languageCode . " only."); /* TO REMOVE */
                    $searchResult = $searchService->findContent( $query, array( "languages" => array( $languageCode ), "useAlwaysAvailable" => false ) );
                }
            }
        }
        else
        {
            $output->writeln("NOT using languageCode: should encompass all languages"); /* TO REMOVE */
            $searchResult = $searchService->findContent( $query );
        }

        /* Results */
        $output->writeln( "Contents found within " . $distance . "km from point (" . $latitude . ", " . $longitude . " matching given search parameters:" );
        foreach( $searchResult->searchHits as $searchHit )
        {
            $output->writeln( $searchHit->valueObject->contentInfo->name );
        }
    }
}

